def formatCellContent(source):
    return (
        source
            .replace('\\', '\\\\')
            .replace('\n', '\\n')
            .replace('\t', '\\t')
            .replace('"', '\\"')
    )



import os
import os.path
from jinja2 import contextfilter
from nbconvert.exporters.templateexporter import TemplateExporter
from dbxnotebookexporter.json.formatCellContent import formatCellContent

class JsonNotebookExporter(TemplateExporter):
    export_from_notebook = 'databricks JSON Notebook'

    def _file_extension_default(self):
        return '.python'

    @property
    def template_path(self):
        return super().template_path + [os.path.dirname(__file__)]

    def _template_file_default(self):
        return 'json_notebook'

    @contextfilter
    def formatCellContent(self, context, source):
        return formatCellContent(source)

    def default_filters(self):
        yield ('formatCellContent', self.formatCellContent)



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['dbxnotebookexporter']

package_data = \
{'': ['*'], 'dbxnotebookexporter': ['databricks/*', 'json/*', 'python/*']}

install_requires = \
['ipython>=7,<8', 'nbconvert>=5,<6']

entry_points = \
{'nbconvert.exporters': ['dbx-json-notebook = '
                         'dbxnotebookexporter.json.JsonNotebookExporter:JsonNotebookExporter',
                         'dbx-python-notebook = '
                         'dbxnotebookexporter.python.PythonNotebookExporter:PythonNotebookExporter']}

setup_kwargs = {
    'name': 'dbx-notebook-exporter',
    'version': '0.3.0',
    'description': 'Databrics Notebook Exporter',
    'long_description': 'Databricks Notebook Exporter for nbconvert\n',
    'author': 'Jiri Koutny',
    'author_email': 'jiri.koutny@datasentics.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/DataSentics/dbx-notebook-exporter',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.5.2',
}


setup(**setup_kwargs)



import os
import os.path

from nbconvert.exporters.templateexporter import TemplateExporter

class DatabricksNotebookExporter(TemplateExporter):
    export_from_notebook = 'databricks Python Notebook'

    def _file_extension_default(self):
        return '.py'

    @property
    def template_path(self):
        return super().template_path + [os.path.dirname(__file__)]

    def _template_file_default(self):
        return 'databricks_notebook'
